@@ -4,6 +4,7 @@ import os
 import sys
 from threading import Lock
 from typing import Optional
+from warnings import warn
 
 from .exceptions import ClientException
 
@@ -60,7 +61,11 @@ class Config:
 
     @property
     def short_url(self) -> str:
-        """Return the short url or raise a ClientException when not set."""
+        """Return the short url.
+
+        :raises: :class:`.ClientException` if it is not set.
+
+        """
         if self._short_url is self.CONFIG_NOT_SET:
             raise ClientException("No short domain specified.")
         return self._short_url
@@ -69,7 +74,7 @@ class Config:
         self,
         site_name: str,
         config_interpolation: Optional[str] = None,
-        **settings: str
+        **settings: str,
     ):
         """Initialize a Config instance."""
         with Config.LOCK:
@@ -80,11 +85,21 @@ class Config:
         self.custom = dict(Config.CONFIG.items(site_name), **settings)
 
         self.client_id = self.client_secret = self.oauth_url = None
-        self.reddit_url = self.refresh_token = self.redirect_uri = None
+        self.reddit_url = self.redirect_uri = None
         self.password = self.user_agent = self.username = None
 
         self._initialize_attributes()
 
+        self._do_not_use_refresh_token = self._fetch_or_not_set("refresh_token")
+        if self._do_not_use_refresh_token != self.CONFIG_NOT_SET:
+            warn(
+                "The ``refresh_token`` configuration setting is deprecated and will be"
+                " removed in PRAW 8. Please use ``token_manager`` to manage your"
+                " refresh tokens.",
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
+
     def _fetch(self, key):
         value = self.custom[key]
         del self.custom[key]
@@ -99,7 +114,7 @@ class Config:
         if key in self._settings:  # Passed in values have the highest priority
             return self._fetch(key)
 
-        env_value = os.getenv("praw_{}".format(key))
+        env_value = os.getenv(f"praw_{key}")
         ini_value = self._fetch_default(key)  # Needed to remove from custom
 
         # Environment variables have higher priority than praw.ini settings
@@ -107,11 +122,14 @@ class Config:
 
     def _initialize_attributes(self):
         self._short_url = self._fetch_default("short_url") or self.CONFIG_NOT_SET
+        self.check_for_async = self._config_boolean(
+            self._fetch_default("check_for_async", True)
+        )
         self.check_for_updates = self._config_boolean(
             self._fetch_or_not_set("check_for_updates")
         )
         self.kinds = {
-            x: self._fetch("{}_kind".format(x))
+            x: self._fetch(f"{x}_kind")
             for x in [
                 "comment",
                 "message",
@@ -126,7 +144,6 @@ class Config:
             "client_id",
             "client_secret",
             "redirect_uri",
-            "refresh_token",
             "password",
             "user_agent",
             "username",
@@ -149,8 +166,7 @@ class Config:
                 setattr(self, attribute, conversion(getattr(self, attribute)))
             except ValueError:
                 raise ValueError(
-                    "An incorrect config type was given for option {}. The "
-                    "expected type is {}, but the given value is {}.".format(
-                        attribute, conversion.__name__, getattr(self, attribute),
-                    )
+                    f"An incorrect config type was given for option {attribute}. The"
+                    f" expected type is {conversion.__name__}, but the given value is"
+                    f" {getattr(self, attribute)}."
                 )
