@@ -14,6 +14,7 @@ API_PATH = {
     "about_unmoderated":       "r/{subreddit}/about/unmoderated/",
     "accept_mod_invite":       "r/{subreddit}/api/accept_moderator_invite",
     "add_subreddit_rule":      "api/add_subreddit_rule",
+    "add_whitelisted":         "api/add_whitelisted",
     "approve":                 "api/approve/",
     "award_thing":             "api/v2/gold/gild",
     "block":                   "api/block",
@@ -143,6 +144,7 @@ API_PATH = {
     "removal_reason":          "api/v1/{subreddit}/removal_reasons/{id}",
     "removal_reasons_list":    "api/v1/{subreddit}/removal_reasons",
     "remove_subreddit_rule":   "api/remove_subreddit_rule",
+    "remove_whitelisted":      "api/remove_whitelisted",
     "remove":                  "api/remove/",
     "reorder_subreddit_rules": "api/reorder_subreddit_rules",
     "report":                  "api/report/",
@@ -184,6 +186,7 @@ API_PATH = {
     "subscribe":               "api/subscribe/",
     "suggested_sort":          "api/set_suggested_sort/",
     "trophies":                "api/v1/user/{user}/trophies",
+    "trusted":                 "prefs/trusted",
     "uncollapse":              "api/uncollapse_message/",
     "unfriend":                "r/{subreddit}/api/unfriend/",
     "unhide":                  "api/unhide/",
@@ -202,6 +205,7 @@ API_PATH = {
     "user_about":              "user/{user}/about/",
     "user_by_fullname":        "/api/user_data_by_account_ids",
     "user_flair":              "r/{subreddit}/api/user_flair_v2",
+    "username_available":      "api/username_available",
     "users_new":               "users/new",
     "users_popular":           "users/popular",
     "users_search":            "users/search",
@@ -211,7 +215,7 @@ API_PATH = {
     "widget_modify":           "r/{subreddit}/api/widget/{widget_id}",
     "widget_order":            "r/{subreddit}/api/widget_order/{section}",
     "widgets":                 "r/{subreddit}/api/widgets",
-    "wiki_edit":               "r/{subreddit}/api/wiki/edit/",
+    "wiki_edit":               "r/{subreddit}/api/wiki/edit",
     "wiki_page":               "r/{subreddit}/wiki/{page}",
     "wiki_page_editor":        "r/{subreddit}/api/wiki/alloweditor/{method}",
     "wiki_page_revisions":     "r/{subreddit}/wiki/revisions/{page}",
