@@ -113,16 +113,19 @@ class CommentForest:
     ) -> List["praw.models.MoreComments"]:
         """Update the comment forest by resolving instances of MoreComments.
 
-        :param limit: The maximum number of :class:`.MoreComments` instances to
-            replace. Each replacement requires 1 API request. Set to ``None`` to
-            have no limit, or to ``0`` to remove all :class:`.MoreComments`
-            instances without additional requests (default: 32).
+        :param limit: The maximum number of :class:`.MoreComments` instances to replace.
+            Each replacement requires 1 API request. Set to ``None`` to have no limit,
+            or to ``0`` to remove all :class:`.MoreComments` instances without
+            additional requests (default: 32).
         :param threshold: The minimum number of children comments a
             :class:`.MoreComments` instance must have in order to be replaced.
-            :class:`.MoreComments` instances that represent "continue this thread"
-            links unfortunately appear to have 0 children. (default: 0).
+            :class:`.MoreComments` instances that represent "continue this thread" links
+            unfortunately appear to have 0 children. (default: 0).
+
         :returns: A list of :class:`.MoreComments` instances that were not replaced.
 
+        :raises: ``prawcore.TooManyRequests`` when used concurrently.
+
         For example, to replace up to 32 :class:`.MoreComments` instances of a
         submission try:
 
@@ -131,8 +134,8 @@ class CommentForest:
             submission = reddit.submission("3hahrw")
             submission.comments.replace_more()
 
-        Alternatively, to replace :class:`.MoreComments` instances within the
-        replies of a single comment try:
+        Alternatively, to replace :class:`.MoreComments` instances within the replies of
+        a single comment try:
 
         .. code-block:: python
 
@@ -143,9 +146,8 @@ class CommentForest:
         .. note::
 
             This method can take a long time as each replacement will discover at most
-            20 new :class:`.Comment` or :class:`.MoreComments` instances. As a result,
-            consider looping and handling exceptions until the method returns
-            successfully. For example:
+            100 new :class:`.Comment` instances. As a result, consider looping and
+            handling exceptions until the method returns successfully. For example:
 
             .. code-block:: python
 
