@@ -8,13 +8,13 @@ from .base import BaseListingMixin
 from .gilded import GildedListingMixin
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
+    from .... import praw
 
 
 class SubListing(BaseListingMixin):
     """Helper class for generating :class:`.ListingGenerator` objects."""
 
-    def __init__(self, reddit: "Reddit", base_path: str, subpath: str):
+    def __init__(self, reddit: "praw.Reddit", base_path: str, subpath: str):
         """Initialize a SubListing instance.
 
         :param reddit: An instance of :class:`.Reddit`.
@@ -35,13 +35,12 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
     def comments(self) -> SubListing:
         r"""Provide an instance of :class:`.SubListing` for comment access.
 
-        For example, to output the first line of all new comments by
-        ``/u/spez`` try:
+        For example, to output the first line of all new comments by ``u/spez`` try:
 
         .. code-block:: python
 
-           for comment in reddit.redditor("spez").comments.new(limit=None):
-               print(comment.body.split("\n", 1)[0][:79])
+            for comment in reddit.redditor("spez").comments.new(limit=None):
+                print(comment.body.split("\n", 1)[0][:79])
 
         """
         return SubListing(self._reddit, self._path, "comments")
@@ -50,13 +49,13 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
     def submissions(self) -> SubListing:
         """Provide an instance of :class:`.SubListing` for submission access.
 
-        For example, to output the title's of top 100 of all time submissions
-        for ``/u/spez`` try:
+        For example, to output the title's of top 100 of all time submissions for
+        ``u/spez`` try:
 
         .. code-block:: python
 
-           for submission in reddit.redditor("spez").submissions.top("all"):
-               print(submission.title)
+            for submission in reddit.redditor("spez").submissions.top("all"):
+                print(submission.title)
 
         """
         return SubListing(self._reddit, self._path, "submitted")
@@ -66,10 +65,14 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
     ) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for items the user has downvoted.
 
-        May raise ``prawcore.Forbidden`` after issuing the request if the user
-        is not authorized to access the list. Note that because this function
-        returns a :class:`.ListingGenerator` the exception may not occur until
-        sometime after this function has returned.
+        :raises: ``prawcore.Forbidden`` if the user is not authorized to access the
+            list.
+
+            .. note::
+
+                Since this function returns a :class:`.ListingGenerator` the exception
+                may not occur until sometime after this function has returned.
+
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -91,10 +94,14 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
     ) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for items the user has gilded.
 
-        May raise ``prawcore.Forbidden`` after issuing the request if the user
-        is not authorized to access the list. Note that because this function
-        returns a :class:`.ListingGenerator` the exception may not occur until
-        sometime after this function has returned.
+        :raises: ``prawcore.Forbidden`` if the user is not authorized to access the
+            list.
+
+            .. note::
+
+                Since this function returns a :class:`.ListingGenerator` the exception
+                may not occur until sometime after this function has returned.
+
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -116,10 +123,14 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
     ) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for items the user has hidden.
 
-        May raise ``prawcore.Forbidden`` after issuing the request if the user
-        is not authorized to access the list. Note that because this function
-        returns a :class:`.ListingGenerator` the exception may not occur until
-        sometime after this function has returned.
+        :raises: ``prawcore.Forbidden`` if the user is not authorized to access the
+            list.
+
+            .. note::
+
+                Since this function returns a :class:`.ListingGenerator` the exception
+                may not occur until sometime after this function has returned.
+
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -141,10 +152,14 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
     ) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for items the user has saved.
 
-        May raise ``prawcore.Forbidden`` after issuing the request if the user
-        is not authorized to access the list. Note that because this function
-        returns a :class:`.ListingGenerator` the exception may not occur until
-        sometime after this function has returned.
+        :raises: ``prawcore.Forbidden`` if the user is not authorized to access the
+            list.
+
+            .. note::
+
+                Since this function returns a :class:`.ListingGenerator` the exception
+                may not occur until sometime after this function has returned.
+
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -153,7 +168,7 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
 
         .. code-block:: python
 
-            for item in reddit.user.me().saved():
+            for item in reddit.user.me().saved(limit=None):
                 print(item.id)
 
         """
@@ -166,10 +181,14 @@ class RedditorListingMixin(BaseListingMixin, GildedListingMixin):
     ) -> Iterator[Any]:
         """Return a :class:`.ListingGenerator` for items the user has upvoted.
 
-        May raise ``prawcore.Forbidden`` after issuing the request if the user
-        is not authorized to access the list. Note that because this function
-        returns a :class:`.ListingGenerator` the exception may not occur until
-        sometime after this function has returned.
+        :raises: ``prawcore.Forbidden`` if the user is not authorized to access the
+            list.
+
+            .. note::
+
+                Since this function returns a :class:`.ListingGenerator` the exception
+                may not occur until sometime after this function has returned.
+
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
