@@ -33,44 +33,44 @@ class Redditor(MessageableMixin, RedditorListingMixin, FullnameMixin, RedditBase
         Suspended/banned accounts will only return the ``name`` and ``is_suspended``
         attributes.
 
-    ==================================== ===============================================
-    Attribute                            Description
-    ==================================== ===============================================
-    ``comment_karma``                    The comment karma for the Redditor.
-    ``comments``                         Provide an instance of :class:`.SubListing`
-                                         for comment access.
-    ``created_utc``                      Time the account was created, represented in
-                                         `Unix Time`_.
-    ``has_verified_email``               Whether or not the Redditor has verified their
-                                         email.
-    ``icon_img``                         The url of the Redditors' avatar.
-    ``id``                               The ID of the Redditor.
-    ``is_employee``                      Whether or not the Redditor is a Reddit
-                                         employee.
-    ``is_friend``                        Whether or not the Redditor is friends with the
-                                         authenticated user.
-    ``is_mod``                           Whether or not the Redditor mods any
-                                         subreddits.
-    ``is_gold``                          Whether or not the Redditor has active Reddit
-                                         Premium status.
-    ``is_suspended``                     Whether or not the Redditor is currently
-                                         suspended.
-    ``link_karma``                       The link karma for the Redditor.
-    ``name``                             The Redditor's username.
-    ``subreddit``                        If the Redditor has created a user-subreddit,
-                                         provides a dictionary of additional attributes.
-                                         See below.
-    ``subreddit["banner_img"]``          The URL of the user-subreddit banner.
-    ``subreddit["name"]``                The fullname of the user-subreddit.
-    ``subreddit["over_18"]``             Whether or not the user-subreddit is NSFW.
-    ``subreddit["public_description"]``  The public description of the user-subreddit.
-    ``subreddit["subscribers"]``         The number of users subscribed to the
-                                         user-subreddit.
-    ``subreddit["title"]``               The title of the user-subreddit.
-    ==================================== ===============================================
+    =================================== ================================================
+    Attribute                           Description
+    =================================== ================================================
+    ``comment_karma``                   The comment karma for the Redditor.
+    ``comments``                        Provide an instance of :class:`.SubListing` for
+                                        comment access.
+    ``submissions``                     Provide an instance of :class:`.SubListing` for
+                                        submission access.
+    ``created_utc``                     Time the account was created, represented in
+                                        `Unix Time`_.
+    ``has_verified_email``              Whether or not the Redditor has verified their
+                                        email.
+    ``icon_img``                        The url of the Redditors' avatar.
+    ``id``                              The ID of the Redditor.
+    ``is_employee``                     Whether or not the Redditor is a Reddit
+                                        employee.
+    ``is_friend``                       Whether or not the Redditor is friends with the
+                                        authenticated user.
+    ``is_mod``                          Whether or not the Redditor mods any subreddits.
+    ``is_gold``                         Whether or not the Redditor has active Reddit
+                                        Premium status.
+    ``is_suspended``                    Whether or not the Redditor is currently
+                                        suspended.
+    ``link_karma``                      The link karma for the Redditor.
+    ``name``                            The Redditor's username.
+    ``subreddit``                       If the Redditor has created a user-subreddit,
+                                        provides a dictionary of additional attributes.
+                                        See below.
+    ``subreddit["banner_img"]``         The URL of the user-subreddit banner.
+    ``subreddit["name"]``               The fullname of the user-subreddit.
+    ``subreddit["over_18"]``            Whether or not the user-subreddit is NSFW.
+    ``subreddit["public_description"]`` The public description of the user-subreddit.
+    ``subreddit["subscribers"]``        The number of users subscribed to the
+                                        user-subreddit.
+    ``subreddit["title"]``              The title of the user-subreddit.
+    =================================== ================================================
 
-
-    .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
+    .. _unix time: https://en.wikipedia.org/wiki/Unix_time
 
     """
 
@@ -146,6 +146,14 @@ class Redditor(MessageableMixin, RedditorListingMixin, FullnameMixin, RedditBase
             self._fullname = fullname
         super().__init__(reddit, _data=_data, _extra_attribute_to_check="_fullname")
 
+    def __setattr__(self, name: str, value: Any):
+        """Objectify the subreddit attribute."""
+        if name == "subreddit" and value:
+            from .user_subreddit import UserSubreddit
+
+            value = UserSubreddit(reddit=self._reddit, _data=value)
+        super().__setattr__(name, value)
+
     def _fetch_username(self, fullname):
         return self._reddit.get(API_PATH["user_by_fullname"], params={"ids": fullname})[
             fullname
@@ -181,8 +189,32 @@ class Redditor(MessageableMixin, RedditorListingMixin, FullnameMixin, RedditBase
 
             reddit.redditor("spez").block()
 
+        .. note::
+
+            Blocking a trusted user will remove that user from your trusted list.
+
+        .. seealso::
+
+            :meth:`.trust`
+
         """
-        self._reddit.post(API_PATH["block_user"], params={"account_id": self.fullname})
+        self._reddit.post(API_PATH["block_user"], params={"name": self.name})
+
+    def distrust(self):
+        """Remove the Redditor from your whitelist of trusted users.
+
+        For example, to remove Redditor ``spez`` from your whitelist:
+
+        .. code-block:: python
+
+            reddit.redditor("spez").distrust()
+
+        .. seealso::
+
+            :meth:`.trust`
+
+        """
+        self._reddit.post(API_PATH["remove_whitelisted"], data={"name": self.name})
 
     def friend(self, note: str = None):
         """Friend the Redditor.
@@ -262,12 +294,7 @@ class Redditor(MessageableMixin, RedditorListingMixin, FullnameMixin, RedditBase
                 print(subreddit.title)
 
         """
-        modded_data = self._reddit.get(API_PATH["moderated"].format(user=self))
-        if "data" not in modded_data:
-            return []
-        else:
-            subreddits = [self._reddit.subreddit(x["sr"]) for x in modded_data["data"]]
-            return subreddits
+        return self._reddit.get(API_PATH["moderated"].format(user=self)) or []
 
     def multireddits(self) -> List["praw.models.Multireddit"]:
         """Return a list of the redditor's public multireddits.
@@ -284,8 +311,8 @@ class Redditor(MessageableMixin, RedditorListingMixin, FullnameMixin, RedditBase
     def trophies(self) -> List["praw.models.Trophy"]:
         """Return a list of the redditor's trophies.
 
-        :returns: A ``list`` of :class:`.Trophy` objects. Return an empty list
-            (``[]``) if the redditor has no trophies.
+        :returns: A ``list`` of :class:`.Trophy` objects. Return an empty list (``[]``)
+            if the redditor has no trophies.
 
         :raises: :class:`.RedditAPIException` if the redditor doesn't exist.
 
@@ -300,6 +327,45 @@ class Redditor(MessageableMixin, RedditorListingMixin, FullnameMixin, RedditBase
         """
         return list(self._reddit.get(API_PATH["trophies"].format(user=self)))
 
+    def trust(self):
+        """Add the Redditor to your whitelist of trusted users.
+
+        Trusted users will always be able to send you PMs.
+
+        Example usage:
+
+        .. code-block:: python
+
+            reddit.redditor("AaronSw").trust()
+
+        Use the ``accept_pms`` parameter of :meth:`.Preferences.update` to toggle your
+        ``accept_pms`` setting between ``"everyone"`` and ``"whitelisted"``. For
+        example:
+
+        .. code-block:: python
+
+            # Accept private messages from everyone:
+            reddit.user.preferences.update(accept_pms="everyone")
+            # Only accept private messages from trusted users:
+            reddit.user.preferences.update(accept_pms="whitelisted")
+
+        You may trust a user even if your ``accept_pms`` setting is switched to
+        ``"everyone"``.
+
+        .. note::
+
+            You are allowed to have a user on your blocked list and your friends list at
+            the same time. However, you cannot trust a user who is on your blocked list.
+
+        .. seealso::
+
+            - :meth:`.distrust`
+            - :meth:`.Preferences.update`
+            - :meth:`.trusted`
+
+        """
+        self._reddit.post(API_PATH["add_whitelisted"], data={"name": self.name})
+
     def unblock(self):
         """Unblock the Redditor.
 
