@@ -11,7 +11,7 @@ from .listing.generator import ListingGenerator
 from .util import stream_generator
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .reddit.subreddit import Subreddit  # noqa: F401
+    from ... import praw
 
 
 class PartialRedditor(SimpleNamespace):
@@ -23,25 +23,27 @@ class Redditors(PRAWBase):
 
     def new(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator["Subreddit"]:
+    ) -> Iterator["praw.models.Subreddit"]:
         """Return a :class:`.ListingGenerator` for new Redditors.
 
         :returns: Redditor profiles, which are a type of :class:`.Subreddit`.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
+
         """
         return ListingGenerator(self._reddit, API_PATH["users_new"], **generator_kwargs)
 
     def popular(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator["Subreddit"]:
+    ) -> Iterator["praw.models.Subreddit"]:
         """Return a :class:`.ListingGenerator` for popular Redditors.
 
         :returns: Redditor profiles, which are a type of :class:`.Subreddit`.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
+
         """
         return ListingGenerator(
             self._reddit, API_PATH["users_popular"], **generator_kwargs
@@ -49,7 +51,7 @@ class Redditors(PRAWBase):
 
     def search(
         self, query: str, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator["Subreddit"]:
+    ) -> Iterator["praw.models.Subreddit"]:
         r"""Return a :class:`.ListingGenerator` of Redditors for ``query``.
 
         :param query: The query string to filter Redditors by.
@@ -58,6 +60,7 @@ class Redditors(PRAWBase):
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
+
         """
         self._safely_add_arguments(generator_kwargs, "params", q=query)
         return ListingGenerator(
@@ -66,15 +69,16 @@ class Redditors(PRAWBase):
 
     def stream(
         self, **stream_options: Union[str, int, Dict[str, str]]
-    ) -> Iterator["Subreddit"]:
+    ) -> Iterator["praw.models.Subreddit"]:
         """Yield new Redditors as they are created.
 
-        Redditors are yielded oldest first. Up to 100 historical Redditors
-        will initially be returned.
+        Redditors are yielded oldest first. Up to 100 historical Redditors will
+        initially be returned.
 
         Keyword arguments are passed to :func:`.stream_generator`.
 
         :returns: Redditor profiles, which are a type of :class:`.Subreddit`.
+
         """
         return stream_generator(self.new, **stream_options)
 
@@ -82,11 +86,13 @@ class Redditors(PRAWBase):
         """Get user summary data by redditor IDs.
 
         :param ids: An iterable of redditor fullname IDs.
+
         :returns: A iterator producing types.SimpleNamespace objects.
 
         Each ID must be prefixed with ``t2_``.
 
         Invalid IDs are ignored by the server.
+
         """
         iterable = iter(ids)
         while True:
