@@ -82,8 +82,10 @@ class User(PRAWBase):
 
         :param user: Checks to see if you are friends with the Redditor. Either an
             instance of :class:`.Redditor` or a string can be given.
+
         :returns: A list of Redditors, or a Redditor if you are friends with the given
             Redditor. The Redditor also has friend attributes.
+
         :raises: An instance of :class:`.RedditAPIException` if you are not friends with
             the specified Redditor.
 
@@ -143,7 +145,7 @@ class User(PRAWBase):
                 warn(
                     "The `None` return value is deprecated, and will raise a"
                     " `ReadOnlyException` beginning with PRAW 8. See documentation for"
-                    " forward compatability options.",
+                    " forward compatibility options.",
                     category=DeprecationWarning,
                     stacklevel=2,
                 )
@@ -170,3 +172,18 @@ class User(PRAWBase):
         return ListingGenerator(
             self._reddit, API_PATH["my_subreddits"], **generator_kwargs
         )
+
+    def trusted(self) -> List["praw.models.Redditor"]:
+        """Return a RedditorList of trusted Redditors.
+
+        To display the usernames of your trusted users and the times at which you
+        decided to trust them, try:
+
+        .. code-block:: python
+
+            trusted_users = reddit.user.trusted()
+            for user in trusted_users:
+                print(f"User: {user.name}, time: {user.date}")
+
+        """
+        return self._reddit.get(API_PATH["trusted"])
