@@ -21,6 +21,7 @@ class Objector:
         """Convert JSON response into an error object.
 
         :param data: The dict to be converted.
+
         :returns: An instance of :class:`~.RedditAPIException`, or ``None`` if ``data``
             doesn't fit this model.
 
@@ -58,6 +59,7 @@ class Objector:
         """Create RedditBase objects from dicts.
 
         :param data: The structured data, assumed to be a dict.
+
         :returns: An instance of :class:`~.RedditBase`.
 
         """
@@ -129,6 +131,9 @@ class Objector:
         elif "username" in data.keys():
             data["name"] = data.pop("username")
             parser = self.parsers[self._reddit.config.kinds["redditor"]]
+        elif {"mod_permissions", "name", "sr", "subscribers"}.issubset(data):
+            data["display_name"] = data["sr"]
+            parser = self.parsers[self._reddit.config.kinds["subreddit"]]
         else:
             if "user" in data:
                 parser = self.parsers[self._reddit.config.kinds["redditor"]]
@@ -137,11 +142,12 @@ class Objector:
         return parser.parse(data, self._reddit)
 
     def objectify(
-        self, data: Optional[Union[Dict[str, Any], List[Any]]]
-    ) -> Optional[Union[RedditBase, Dict[str, Any], List[Any]]]:
+        self, data: Optional[Union[Dict[str, Any], List[Any], bool]]
+    ) -> Optional[Union[RedditBase, Dict[str, Any], List[Any], bool]]:
         """Create RedditBase objects from data.
 
         :param data: The structured data.
+
         :returns: An instance of :class:`~.RedditBase`, or ``None`` if given ``data`` is
             ``None``.
 
@@ -151,6 +157,8 @@ class Objector:
             return None
         if isinstance(data, list):
             return [self.objectify(item) for item in data]
+        if isinstance(data, bool):  # Reddit.username_available
+            return data
         if "json" in data and "errors" in data["json"]:
             errors = data["json"]["errors"]
             if len(errors) > 0:
@@ -163,7 +171,10 @@ class Objector:
             return parser.parse(data, self._reddit)
         if {"kind", "data"}.issubset(data) and data["kind"] in self.parsers:
             parser = self.parsers[data["kind"]]
-            return parser.parse(data["data"], self._reddit)
+            if data["kind"] == "ModeratedList":
+                return parser.parse(data, self._reddit)
+            else:
+                return parser.parse(data["data"], self._reddit)
         if "json" in data and "data" in data["json"]:
             if "websocket_url" in data["json"]["data"]:
                 return data
